**********
Snoweb SVG
**********

.. image:: https://img.shields.io/pypi/v/snowebsvg
    :target: https://pypi.org/project/snowebsvg/

.. image:: https://img.shields.io/pypi/pyversions/snowebsvg
    :target: https://pypi.org/project/snowebsvg/

.. image:: https://readthedocs.org/projects/snoweb-svg/badge/?version=latest
    :target: https://snoweb-svg.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/Aleksi44/snoweb-svg/badge.svg?branch=master
    :target: https://coveralls.io/github/Aleksi44/snoweb-svg?branch=master


Snoweb SVG is a database of SVGs optimized and animated built in HTML and CSS.


Features
********

- Svg code in html and css
- No javascript required
- Themes with css class or prefers-color-scheme
- Variant manager with Glassmorphism
- Possible integration with Django and Wagtail
- Animation on hover

Find all Svg at `www.snoweb-svg.com <https://www.snoweb-svg.com/svg/>`_.

Documentation available `here <https://snoweb-svg.readthedocs.io/en/latest/>`_.

Made with ❤ by `Snoweb <https://www.snoweb.io/fr/>`_.